@@ -228,7 +228,10 @@ parole_gst_realize (GtkWidget *widget)
     ParoleGst *gst;
     GtkAllocation *allocation = g_new0 (GtkAllocation, 1);
     GdkWindowAttr attr;
+#if GTK_CHECK_VERSION(3,22,0)
+#else
     GdkRGBA color;
+#endif
     gint mask;
 
     gtk_widget_set_realized (widget, TRUE);
@@ -458,10 +461,6 @@ static void
 parole_gst_set_video_overlay (ParoleGst *gst)
 {
     GstElement *video_sink;
-#if GTK_CHECK_VERSION(3,8,0)
-#else
-    gchar *videosink;
-#endif
 
     g_object_get (G_OBJECT (gst->priv->playbin),
                   "video-sink", &video_sink,
@@ -478,18 +477,6 @@ parole_gst_set_video_overlay (ParoleGst *gst)
                           GDK_WINDOW_XID ( gtk_widget_get_window(GTK_WIDGET (gst)) ));
 #endif
 
-#if GTK_CHECK_VERSION(3,8,0)
-#else
-    g_object_get (G_OBJECT (gst->priv->conf),
-                             "videosink", &videosink,
-                             NULL);
-    if (g_strcmp0(videosink, "ximagesink") == 0)
-    {
-        g_object_set(video_sink, "autopaint-colorkey", FALSE,
-                                 "colorkey", 0x080810, NULL);
-    }
-#endif
-
     gst_object_unref (video_sink);
 }
 
@@ -605,12 +592,17 @@ parole_gst_query_duration (ParoleGst *gst)
 #endif
                                 &absolute_duration);
 
+    if (absolute_duration < 0)
+    {
+        absolute_duration = 0;
+    }
+
     if (gst_time == GST_FORMAT_TIME)
     {
         duration =  absolute_duration / GST_SECOND;
         live = ( absolute_duration == 0 );
 
-        TRACE ("Duration %" G_GINT64_FORMAT "is_live=%d", duration, live);
+        TRACE ("Duration %" G_GINT64_FORMAT ", is_live=%d", duration, live);
 
         g_object_set (G_OBJECT (gst->priv->stream),
                       "absolute-duration", absolute_duration,
@@ -1033,6 +1025,10 @@ parole_gst_tag_list_get_cover_external (ParoleGst *gst)
                   NULL);
 
     filename = g_filename_from_uri(uri, NULL, NULL);
+    if (!filename)
+    {
+        return NULL;
+    }
 
     directory = g_path_get_dirname(filename);
 
@@ -1291,7 +1287,7 @@ parole_gst_get_meta_data_cdda (ParoleGst *gst, GstTagList *tag)
 }
 
 static void
-parole_gst_get_meta_data_local_file (ParoleGst *gst, GstTagList *tag)
+parole_gst_get_meta_data_file (ParoleGst *gst, GstTagList *tag)
 {
     gchar *str;
     GDate *date;
@@ -1359,9 +1355,12 @@ parole_gst_get_meta_data_local_file (ParoleGst *gst, GstTagList *tag)
     if ( gst_tag_list_get_uint (tag, GST_TAG_TRACK_NUMBER, &integer) )
     {
         TRACE ("track:%i", integer);
-        g_object_set (G_OBJECT (gst->priv->stream),
-                      "track", integer,
-                      NULL);
+        if (integer < 100)
+        {
+            g_object_set (G_OBJECT (gst->priv->stream),
+                          "track", integer,
+                          NULL);
+        }
     }
 
     if ( gst_tag_list_get_uint (tag, GST_TAG_BITRATE, &integer) )
@@ -1419,7 +1418,8 @@ parole_gst_get_meta_data (ParoleGst *gst, GstTagList *tag)
     switch ( media_type )
     {
         case PAROLE_MEDIA_TYPE_LOCAL_FILE:
-            parole_gst_get_meta_data_local_file (gst, tag);
+        case PAROLE_MEDIA_TYPE_REMOTE:
+            parole_gst_get_meta_data_file (gst, tag);
             break;
         case PAROLE_MEDIA_TYPE_CDDA:
             parole_gst_get_meta_data_cdda (gst, tag);
@@ -1427,7 +1427,6 @@ parole_gst_get_meta_data (ParoleGst *gst, GstTagList *tag)
         case PAROLE_MEDIA_TYPE_DVD:
             parole_gst_get_meta_data_dvd (gst);
             break;
-        case PAROLE_MEDIA_TYPE_REMOTE:
         case PAROLE_MEDIA_TYPE_UNKNOWN:
             parole_gst_get_meta_data_unknown (gst);
             break;
