@@ -360,11 +360,7 @@ delete_event_cb (GtkWidget *widget, GdkEvent *ev, TrayProvider *tray)
 
     gtk_box_pack_start (GTK_BOX (content_area), check, TRUE, TRUE, 0);
 
-#if GTK_CHECK_VERSION(3,12,0)
     gtk_widget_set_margin_start (GTK_WIDGET(check), 3);
-#else
-    gtk_widget_set_margin_left (GTK_WIDGET(check), 3);
-#endif
 
     gtk_widget_show_all( GTK_WIDGET(dialog) );
 
